from setuptools import setup, find_packages

setup(
    name="audits",
    version="0.0.1",
    packages=find_packages(),
    description="Project under active development. Placeholder description, will fill out soon.",
)
